*** Settings ***
Library    OperatingSystem
Library    BuiltIn
Library    JSONLibrary
Library    Collections    
Default Tags     USE_POLLING

Resource    GenericKeywords.robot
Resource    SOL005-Keywords.robot
Resource    SOL003-Keywords.robot




*** Test Cases ***
Instantiate an NS Instance
    Check Preconditions
    POST Create a new NsInstance
    Set Suite Variable    ${nsInstanceId}    ${response['body']['id']}
    POST Instantiate a nsInstance
    GET LCM Operation Occurrency Id
    Check NSInstance Status        
    Check Postconditions    
    


*** Keywords ***
Check Preconditions
    [Tags]    PRECONDITION_CHECK
    Check NSD is on-boarded 
    Check VNF packages are on-boarded
    Check PNF archives are on-boarded


Check Postconditions
    [Tags]    POSTCONDITION_CHECK
    GET Information about an individual NS Instance
    Should Be Equal As Strings    ${response['body']['nsState']}    INSTANTIATED    


Check NSD is on-boarded 
    GET Individual NSD Information
    Set Suite Variable    ${vnfPkgIds}    ${response['body']['vnfPkgIds']}
    Set Suite Variable    ${pnfdInfoIds}    ${response['body']['pnfdInfoIds']}
    
    
Check VNF packages are on-boarded
    ${length}=    Get Length    ${vnfPkgIds}
    :FOR    ${i}    IN RANGE    0    ${length}
    \    ${value}    Get From List    ${vnfPkgIds}    ${i}
    \    Set Suite Variable    ${vnfPackageId}    ${value}
    \    GET Individual VNF Package Information
    
    
Check PNF archives are on-boarded
    ${length}=    Get Length    ${pnfdInfoIds}
    :FOR    ${i}    IN RANGE    0    ${length}
    \    ${value}    Get From List    ${pnfdInfoIds}    ${i}
    \    Set Suite Variable    ${pnfdInfoId}    ${value}
    \    GET Individual PNF Descriptor
    
Subscribe to NFVO to receive instantiation notifications 
    [Tags]    USE_SUBSCRIPTIONS
    POST subscriptions
    

Check NSInstance Status
    GET information about multiple VNF instances
    Set Suite Variable    ${vnfInstances}    ${response['body']}
    GET status information about multiple VNF LCM Operation OCC with "fields"
    Set Suite Variable    ${vnfLcmOpOccs}    ${response['body']}
    Get status information about Individual NS LCM occurrences
    ${value}=  Run Keyword And Return Status    Should Not Be Equal As Strings  ${response['body']['operationState']}    COMPLETED  
    Run Keyword If    ${value} == True
    ...    Check NS and VNF Status  


    
Check NS and VNF Status
    Wait Until Keyword Succeeds    20m    30s    
    ...    Get affected VNFs



Get affected VNFs
    ${length}=    Get Length    ${vnfLcmOpOccs}
    :FOR     ${i}     IN RANGE    0   ${length}
    \    ${value}    Get From List    ${vnfLcmOpOccs}    ${i}
    \    Get information about VNF instances    ${value['id']}
    \    Should Be Equal As Strings    ${response['body']['operationState']}    COMPLETED    
    
