*** Settings ***
Resource   environment/sol003-variables.txt
Resource   environment/variables.txt
Resource   GenericKeywords.robot
Library    JSONSchemaLibrary    schemas/
Library    OperatingSystem
Library    JSONLibrary
Library    String
Library    REST    ${VNFM_SCHEMA}://${VNFM_HOST}:${VNFM_PORT}    ssl_verify=false
Library    JSONSchemaLibrary    schemas/


*** Keywords ***
GET information about multiple VNF instances  
    [Documentation]    Test ID: 7.3.1.1.2
    ...    Test title: GET information about multiple VNF instances
    ...    Test objective: The objective is to query information about multiple VNF instances
    ...    Pre-conditions:  
    ...    Reference: clause 5.4.2.3.2 - ETSI GS NFV-SOL 003 [1] v2.4.1
    ...    Config ID: Config_prod_VNFM
    ...    Applicability: 
    ...    Post-Conditions: 
    GET multiple vnfInstances
    Check HTTP Response Status Code Is    200
    Check HTTP Response Body Json Schema Is    VnfInstances
    

GET multiple vnfInstances	
    Log    Query VNF The GET method queries information about multiple VNF instances.
    Set Headers  {"Accept":"${ACCEPT_JSON}"}  
    Set Headers  {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${VNFM_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${VNFM_AUTHORIZATION}"}
    Log    Execute Query and validate response
    Get    ${vnfm_apiRoot}/vnflcm/${vnfm_apiVersion}/vnf_instances    
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse} 
	
GET status information about multiple VNF LCM Operation OCC with "fields"   
    [Documentation]    Test ID: 7.3.1.11.7
    ...    Test title: GET status information about multiple VNF LCM Operation OCC with "fields"
    ...    Test objective: The objective is to test that GET method retrieve Query status information about multiple VNF lifecycle management operation occurrences.
    ...    Pre-conditions: none
    ...    Reference: clause 5.4.12.3.2 - ETSI GS NFV-SOL 003 [1] v2.4.1
    ...    Config ID: Config_prod_VNFM
    ...    Applicability: none
    ...    Post-Conditions: none   
    Get VNF LCM Operation occurrences with fields attribute selector
    Check HTTP Response Status Code Is    200
    Check HTTP Response Body Json Schema Is    VnfLcmOpOccs
    
Get VNF LCM Operation occurrences with fields attribute selector
    Log    Query status information about multiple VNF lifecycle management operation occurrences, using fields
    Set Headers    {"Accept": "${ACCEPT_JSON}"}
    Run Keyword If    ${VNFM_AUTH_USAGE} == 1    Set Headers    {"Authorization": "${VNFM_AUTHORIZATION}"}
    GET    ${vnfm_apiRoot}/vnflcm/${vnfm_apiVersion}/vnf_lcm_op_occs?fields=${fields}
    ${output}=    Output    response
    Set Suite Variable    ${response}    ${output}
    

Get information about VNF instances 
    [Arguments]    ${vnfLcmOpOccId}
    [Documentation]    Test ID: 7.3.1.12.2
    ...    Test title: Get information about multiple VNF instances
    ...    Test objective: The objective is to test that this method retrieve information about a VNF lifecycle management operation occurrence 
    ...    Pre-conditions: none
    ...    Reference: clause 5.4.13.3.2 - ETSI GS NFV-SOL 003 [1] v2.4.1
    ...    Config ID: Config_prod_VNFM
    ...    Applicability: none
    ...    Post-Conditions: none 
    Get VNF LCM Operation Occurrance    ${vnfLcmOpOccId}
    Check HTTP Response Status Code Is    200
    Check HTTP Response Body Json Schema Is    VnfLcmOpOcc
    

    

Get VNF LCM Operation Occurrance
    [Arguments]     ${vnfLcmOpOccId}
    Log    Query status information about multiple VNF lifecycle management operation occurrences.
    Set Headers  {"Accept":"${ACCEPT_JSON}"}  
    Run Keyword If    ${VNFM_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${VNFM_AUTHORIZATION}"}
    Log    Execute Query and validate response
    Get    ${vnfm_apiRoot}/vnflcm/${vnfm_apiVersion}/vnf_lcm_op_occs/${vnfLcmOpOccId}
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse}	
	

GET individual vnfInstance
    log    Trying to get information about an individual VNF instance
    Set Headers    {"Accept":"${ACCEPT_JSON}"}  
    Set Headers    {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${VNFM_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${VNFM_AUTHORIZATION}"}
    Get    ${vnfm_apiRoot}/vnflcm/${vnfm_apiVersion}/vnf_instances/${vnfInstanceId} 		
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse}
