*** Settings ***
Resource   environment/sol005-variables.txt
Resource   environment/variables.txt
Resource   GenericKeywords.robot
Library    JSONSchemaLibrary    schemas/
Library    OperatingSystem
Library    JSONLibrary
Library    String
Library    REST    ${NFVO_SCHEMA}://${NFVO_HOST}:${NFVO_PORT}    ssl_verify=false
Library    JSONSchemaLibrary    schemas/


*** Keywords ***
GET Individual NSD Information
    [Documentation]    Test ID: 5.3.1.2.1
    ...    Test title: GET Individual Network Service Descriptor Information
    ...    Test objective: The objective is to test the retrieval of an individual Network Service Descriptor information and perform a JSON schema validation of the collected data structure
    ...    Pre-conditions: One or more Network Service Descriptors are onboarded in the NFVO.
    ...    Reference: clause 5.4.3.3.2 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: none
    GET Individual Network Service Descriptor Information
    Check HTTP Response Status Code Is    200
    Check HTTP Response Body Json Schema Is   NsdInfo
    Check HTTP Response Header Contains ETag
    Check HTTP Response Body NsdInfo Identifier matches the requested Network Service Descriptor Information
    

POST Create a new NsInstance
    [Documentation]    Test ID: 5.3.2.1.1
    ...    Test title: POST Create a new NsInstance
    ...    Test objective: The objective is to test the creation of a new Ns Instances and perform a JSON schema validation of the collected instance data structure
    ...    Pre-conditions: None.
    ...    Reference: clause 6.4.2.3.1 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none.
    ...    Post-Conditions: A Ns instance is instantiated.
    POST New nsInstance
    Check HTTP Response Status Code Is    201
    Check HTTP Response Header Contains    Location
    Check HTTP Response Body Json Schema Is    NsInstance
    
POST Instantiate a nsInstance
    [Documentation]    Test ID: 5.3.2.3.1
    ...    Test title: POST Instantiate a nsInstance
    ...    Test objective: The objective is to test that POST method instantiate a new NS instance
    ...    Pre-conditions: none
    ...    Reference: clause 6.4.4.3.1 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: The NS instance is instantiated on the NFVO
    POST Instantiate nsInstance
    Check HTTP Response Status Code Is    202
    Check HTTP Response Header Contains    Location
	
Get status information about Individual NS LCM occurrences   
    [Documentation]    Test ID: 5.3.2.9.2
    ...    Test title: Get status information about Individual NS LCM occurrences
    ...    Test objective: The objective is to test that GET method returns the LCM occurrence of the NS
    ...    Pre-conditions: none
    ...    Reference: clause 6.4.10.3.2 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: none
	GET Individual NS LCM OP Occurrence
	Check HTTP Response Status Code Is    200
	Check HTTP Response Body Json Schema Is    NsLcmOpOcc
	
GET Individual VNF Package Information
    [Documentation]    Test ID: 5.3.5.2.1
    ...    Test title: GET Individual VNF Package
    ...    Test objective: The objective is to test the retrieval of an individual VNF package information perform a JSON schema validation of the collected data structure
    ...    Pre-conditions: One or more VNF packages are onboarded in the NFVO.
    ...    Reference: clause 9.4.3.3.2 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: none
    GET Individual VNF Package
    Check HTTP Response Status Code Is    200
    Check HTTP Response Body Json Schema Is   VnfPkgInfo
    Check HTTP Response Body vnfPkgInfo Identifier matches the requested VNF Package
	

GET Information about an individual NS Instance
    [Documentation]    Test ID: 5.3.2.2.2
    ...    Test title: GET Information about an individual NS Instance
    ...    Test objective: The objective is to test that GET method returns an individual NS instance
    ...    Pre-conditions: none
    ...    Reference: clause 6.4.3.3.2 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: none
    GET IndividualNSInstance
    Check HTTP Response Status Code Is    200
    Check HTTP Response Body Json Schema Is    NsInstance


GET Individual PNF Descriptor
    [Documentation]    Test ID: 5.3.1.5.1
    ...    Test title: GET Individual PNF Descriptor Information
    ...    Test objective: The objective is to test the retrieval of an individual PNF Descriptor information and perform a JSON schema validation of the collected data structure
    ...    Pre-conditions: One or more PNF Descriptors are onboarded in the NFVO.
    ...    Reference: clause 5.4.6.3.2 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: none
    GET Individual PNF Descriptor Information
    Check HTTP Response Status Code Is    200
    Check HTTP Response Body Json Schema Is   PnfdInfo
    Check HTTP Response Header Contains ETag
    Check HTTP Response Body PnfdInfo Identifier matches the requested PNF Descriptor Information
    
POST Terminate a NSInstance
    [Documentation]    Test ID: 5.3.2.7.1
    ...    Test title: POST Terminate a NSInstance
    ...    Test objective: The objective is to test that POST method terminate the NS
    ...    Pre-conditions: NS instance in INSTANTIATED state
    ...    Reference: clause 6.4.8.3.1 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: NS instance has NOT_INSTANTIATED state
    POST Terminate NSInstance
    Check HTTP Response Status Code Is    202
    Check HTTP Response Header Contains    Location
    Check resource not_instantiated
    
DELETE Individual NSInstance
     [Documentation]    Test ID: 5.3.2.2.5
    ...    Test title: DELETE Individual NSInstance
    ...    Test objective: The objective is to test that DELETE method delete a not INSTANTIATED NS instance
    ...    Pre-conditions: NS instance is not INSTANTIATED .
    ...    Reference: clause 6.4.3.3.5 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: The NS instance is deleted from the NFVO
    DELETE Single NSInstance    
    Check HTTP Response Status Code Is    204
    
POST Update a NSInstance
    [Documentation]    Test ID: 5.3.2.5.1
    ...    Test title: POST Update a NSInstance
    ...    Test objective: The objective is to test that POST method update a NS instance
    ...    Pre-conditions: an existing NS Instance 
    ...    Reference: clause 6.4.6.3.1 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: The  NS instance is updated on the NFVO
    POST Update NSInstance
    Check HTTP Response Status Code Is    202
    Check HTTP Response Header Contains    Location
    

POST Scale a nsInstance
    [Documentation]    Test ID: 5.3.2.4.1
    ...    Test title: POST Scale a nsInstance
    ...    Test objective: The objective is to test that POST method scales NS instance
    ...    Pre-conditions: the resource is in NOT_INSTANTIATED state
    ...    Reference: clause 6.4.5.3.1 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: none
    POST scale nsInstance
    Check HTTP Response Status Code Is    202
    Check HTTP Response Header Contains    Location
    
POST Scale a nsInstance using VNF scale to level
    [Documentation]    Test ID: 5.3.2.4.1
    ...    Test title: POST Scale a nsInstance
    ...    Test objective: The objective is to test that POST method scales NS instance
    ...    Pre-conditions: the resource is in NOT_INSTANTIATED state
    ...    Reference: clause 6.4.5.3.1 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: none
    POST scale nsInstance using VNF scale to level 
    Check HTTP Response Status Code Is    202
    Check HTTP Response Header Contains    Location
    
Create new VNF Package Resource
    [Documentation]    Test ID: 5.3.5.1.11
    ...    Test title: Create new VNF Package Resource
    ...    Test objective: The objective is to test the creation of a new VNF Package Resource and perform the JSON schema validation of the returned structure
    ...    Pre-conditions: none
    ...    Reference: clause 9.4.2.3.1 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: The VNF Package Resource is successfully created on the NFVO
    Send Post Request to create new VNF Package Resource
    Check HTTP Response Status Code Is    201
    Check HTTP Response Body Json Schema Is   VnfPkgInfo
    Check HTTP Response Header Contains    Location
    Check Postcondition VNF Package Resource Exists


Upload VNF Package Content
    [Documentation]    Test ID: 5.3.5.4.8
    ...    Test title: Upload VNF Package Content
    ...    Test objective: The objective is to test the upload of a VNF Package Content in Zip format.
    ...    Pre-conditions: One or more VNF Packages are onboarded in the NFVO.
    ...    Reference: clause 9.4.5.3.4 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: The VNF Package content is successfully uploaded and available in the NFVO
    Send PUT Request to upload VNF Package Content
    Check HTTP Response Status Code Is    204
    Check Postcondition VNF Package Content is uploaded and available in the NFVO

Upload VNF Package Content from URI
    [Documentation]    Test ID: 5.3.5.5.1
    ...    Test title: Upload VNF Package Content from URI
    ...    Test objective: The objective is to test the upload of a VNF Package Content from URI.
    ...    Pre-conditions: One or more VNF Packages are in onboarding state CREATED in the NFVO.
    ...    Reference: clause 9.4.6.3.1 - ETSI GS NFV-SOL 005 [3] v2.4.1
    ...    Config ID: Config_prod_NFVO
    ...    Applicability: none
    ...    Post-Conditions: none
    Send POST Request to upload VNF Package Content from URI
    Check HTTP Response Status Code Is    202
    Check HTTP Response Body is Empty
    
GET Individual Network Service Descriptor Information
    Log    The GET method reads information about an individual NS descriptor
    Set Headers    {"Accept": "${ACCEPT_JSON}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization": "${NFVO_AUTHORIZATION}"}
    GET    ${nfvo_apiRoot}/nsd/${nfvo_apiVersion}/ns_descriptors/${nsdInfoId}
    ${output}=    Output    response
    Set Suite Variable    ${response}    ${output}
    
Check HTTP Response Body NsdInfo Identifier matches the requested Network Service Descriptor Information
    Log    Going to validate info retrieved
    Should Be Equal    ${response['body']['id']}    ${nsdInfoId} 
    Log    NSD identifier as expected
    
POST New nsInstance
    Log    Create NS instance by POST to ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances
    Set Headers  {"Accept":"${ACCEPT_JSON}"}  
    Set Headers  {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    ${body}=    Get File    jsons/CreateNsRequest.json
    Post    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances    ${body}
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse}


    
 POST Instantiate nsInstance
    Log    Trying to Instantiate a ns Instance
    Set Headers  {"Accept":"${ACCEPT_JSON}"}  
    Set Headers  {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    ${body}=    Get File    jsons/InstantiateNsRequest.json
    Post    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances/${nsInstanceId}/instantiate    ${body}
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse}
	

GET LCM Operation Occurrency Id
    Log    Storing in lcmOpOccId the provided value
    ${locationUri}=   Split String From Right    ${response['headers']['Location']}    /    1
    Set Suite Variable    ${nsLcmOpOccId}     ${locationUri}
    

GET Individual NS LCM OP Occurrence
    Log    Query status information about individual NS lifecycle management operation occurrence.
	Set Headers  {"Accept":"${ACCEPT_JSON}"}  
	Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
	Log    Execute Query and validate response
	Get    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_lcm_op_occs/${nsLcmOpOccId} 	
	${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse}	
	
	
GET IndividualNSInstance
    Log    Trying to get information about an individual NS instance
    Set Headers    {"Accept":"${ACCEPT_JSON}"}  
    Set Headers    {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    Get    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances/${nsInstanceId}
    ${Etag}=    Output    response headers ETag
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse} 
	

GET Individual VNF Package
    Log    Trying to get a VNF Package present in the NFVO Catalogue
    Set Headers    {"Accept": "${ACCEPT_JSON}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization": "${NFVO_AUTHORIZATION}"}
    GET    ${nfvo_apiRoot}/vnfpkgm/${nfvo_apiVersion}/vnf_packages/${vnfPackageId}
    ${output}=    Output    response
    Set Suite Variable    ${response}    ${output}
    
Check HTTP Response Body vnfPkgInfo Identifier matches the requested VNF Package
    Log    Going to validate pacakge info retrieved
    Should Be Equal    ${response['body']['id']}    ${vnfPackageId} 
    Log    Pacakge identifier as expected
    
GET Individual PNF Descriptor Information
    Log    The GET method reads information about an individual PNF descriptor
    Set Headers    {"Accept": "${ACCEPT_JSON}"}
    Run Keyword If    ${NFVo_AUTH_USAGE} == 1    Set Headers    {"Authorization": "${NFVO_AUTHORIZATION}"}
    GET    ${nfvo_apiRoot}/nsd/${nfvo_apiVersion}/pnf_descriptors/${pnfdInfoId}
    ${output}=    Output    response
    Set Suite Variable    ${response}    ${output}
    
Check HTTP Response Body PnfdInfo Identifier matches the requested PNF Descriptor Information
    Log    Going to validate info retrieved
    Should Be Equal    ${response['body']['id']}    ${pnfdInfoId} 
    Log    PNFD identifier as expected
    
POST Terminate NSInstance
	Log    Trying to Instantiate a Terminate NS Instance
    Set Headers  {"Accept":"${ACCEPT_JSON}"}  
    Set Headers  {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    ${body}=    Get File    jsons/TerminateNsRequest.json
	Post    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances/${nsInstanceId}/terminate    ${body}
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse} 
	
Check resource not_instantiated
    Set Headers    {"Accept":"${ACCEPT_JSON}"}  
    Set Headers    {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    Get    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances/${nsInstanceId} 
    String    response body nsState    NOT_INSTANTIATED
    
DELETE Single NSInstance
    log    Trying to delete an individual VNF instance
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    Delete    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances/${nsInstanceId}
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse} 
	
POST Update NSInstance
	Log    Trying to Instantiate a Update NS Instance
    Set Headers  {"Accept":"${ACCEPT_JSON}"}  
    Set Headers  {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    ${body}=    Get File    jsons/UpdateNsRequest.json
	Post    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances/${nsInstanceId}/update    ${body}
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse} 
	
POST scale nsInstance
	Log    Trying to Instantiate a scale NS Instance
    Set Headers  {"Accept":"${ACCEPT_JSON}"}  
    Set Headers  {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    ${body}=    Get File    jsons/ScaleNsRequest.json
	Post    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances/${nsInstanceId}/scale    ${body}
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse} 
	
POST scale nsInstance using VNF scale to level
	Log    Trying to Instantiate a scale NS Instance
    Set Headers  {"Accept":"${ACCEPT_JSON}"}  
    Set Headers  {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    ${body}=    Get File    jsons/ScaleNsToLevelRequest.json
	Post    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/ns_instances/${nsInstanceId}/scale    ${body}
    ${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse}
	
POST subscriptions
    Log    Create subscription instance by POST to ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/subscriptions
    Set Headers  {"Accept":"${ACCEPT_JSON}"}  
    Set Headers  {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization":"${NFVO_AUTHORIZATION}"}
    ${body}=    Get File    jsons/LccnSubscriptionRequest.json
    Post    ${nfvo_apiRoot}/nslcm/${nfvo_apiVersion}/subscriptions    ${body}    
	${outputResponse}=    Output    response
	Set Global Variable    ${response}    ${outputResponse}


Send Post Request to create new VNF Package Resource
    Log    Creating a new VNF Package
    Set Headers    {"Accept": "${ACCEPT_JSON}"}
    Set Headers    {"Content-Type": "${CONTENT_TYPE}"}
    ${body}=    Get File    jsons/CreateVnfPkgInfoRequest.json
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization": "${NFVO_AUTHORIZATION}"}
    POST    ${nfvo_apiRoot}/vnfpkgm/${nfvo_apiVersion}/vnf_packages    ${body}
    ${output}=    Output    response
    Set Suite Variable    ${response}    ${output}
    Set Suite Variable    ${vnfPackageId}    ${response['body']['id']}
    
    
Check Postcondition VNF Package Resource Exists
    Log    Checking that nsd info exists
    Set Headers    {"Accept": "${ACCEPT_JSON}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization": "${NFVO_AUTHORIZATION}"}
    GET    ${nfvo_apiRoot}/vnfpkgm/${nfvo_apiVersion}/vnf_packages/${vnfPackageId}
    ${output}=    Output    response
    Set Suite Variable    ${response}    ${output}
    Check HTTP Response Status Code Is    200
    Check HTTP Response Body Json Schema Is    VnfPkgInfo

    
Send PUT Request to upload VNF Package Content
    Log    Trying to perform a PUT. This method upload the content of a NSD
    Set Headers    {"Accept": "${ACCEPT_ZIP}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization": "${NFVO_AUTHORIZATION}"}
    ${body}=  Get Binary File     files/vnfPackage.zip
    PUT    ${nfvo_apiRoot}/vnfpkgm/${nfvo_apiVersion}/vnf_packages/${vnfPackageId}/package_content    ${body}
    ${response}=    Output    response body
    Should Be Empty    ${response} 
    ${output}=    Output    response
    Set Suite Variable    ${response}    ${output}
    
Check Postcondition VNF Package Content is uploaded and available in the NFVO
    Log    Trying to get a VNF Package Content
    Set Headers    {"Accept": "${ACCEPT_ZIP}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization": "${NFVO_AUTHORIZATION}"}
    GET    ${nfvo_apiRoot}/vnfpkgm/${nfvo_apiVersion}/vnf_packages/${vnfPackageId}/package_content
    Integer    response status    200
    
Send POST Request to upload VNF Package Content from URI
    Log    Trying to perform a POST. The POST method provides the information for the NFVO to get the content of a VNF package.
    Set Headers    {"Content-Type": "${CONTENT_TYPE}"}
    Run Keyword If    ${NFVO_AUTH_USAGE} == 1    Set Headers    {"Authorization": "${NFVO_AUTHORIZATION}"}
    ${body}=    Get File    jsons/UploadVnfPkgFromUriRequest.json
    POST    ${nfvo_apiRoot}/vnfpkgm/${nfvo_apiVersion}/vnf_packages/${vnfPackageId}/package_content/upload_from_uri    ${body}
    ${output}=    Output    response
    Set Suite Variable    ${response}    ${output}
    
Verify VNF Package Resource Creation PostCondition
    Log    onboardingState, operationalState and usageState shall be set respectively in CREATED, DISABLED and NOT_IN_USE
    Should Be Equal As Strings    ${response['body']['onboardingState']}    CREATED    
    Should Be Equal As Strings    ${response['body']['operationalState']}    DISABLED    
    Should Be Equal As Strings    ${response['body']['usageState']}    NOT_IN_USE    
    
Verify VNF Package Upload PostCondition
    Log    onboardingState, operationalState and usageState shall be set respectively in ONBOARDED, ENABLED and NOT_IN_USE
    Should Be Equal As Strings    ${response['body']['onboardingState']}    ONBOARDED    
    Should Be Equal As Strings    ${response['body']['operationalState']}    ENABLED    
    Should Be Equal As Strings    ${response['body']['usageState']}    NOT_IN_USE 
